@@ -10,21 +10,21 @@ class Document(Resource):
         Create an `Attachment` object from `name` and the settings
         for the current database.
         """
-        return Attachment(self._make_url(name), **kwargs)
+        return Attachment(self._make_url(name), session=self._session, **kwargs)
 
     def view(self, method, function, **kwargs):
         """
         Create a `View` object by joining `method` and `function`.
         """
         path = '/'.join([method, function])
-        return View(self._make_url(path), **kwargs)
+        return View(self._make_url(path), session=self._session, **kwargs)
 
     def merge(self, change, **kwargs):
         """
         Merge `changes` into the document,
         and then `PUT` the updated document back to the server
         """
-        doc = self.get().json()
+        doc = self.get().result().json()
         doc.update(change)
         return self.put(params=doc, **kwargs)
 
